@@ -1,10 +1,9 @@
-from __future__ import absolute_import, unicode_literals
+from unittest.mock import Mock
 
 import pytest
 
 import amqp.exceptions
 from amqp.exceptions import AMQPError, error_for_code
-from case import Mock
 
 AMQP_EXCEPTIONS = (
     'ConnectionError', 'ChannelError',
@@ -29,7 +28,7 @@ class test_AMQPError:
 
     @pytest.mark.parametrize("amqp_exception", AMQP_EXCEPTIONS)
     def test_str_subclass(self, amqp_exception):
-        exp = '<{}: unknown error>'.format(amqp_exception)
+        exp = f'<{amqp_exception}: unknown error>'
         exception_class = getattr(amqp.exceptions, amqp_exception)
         assert str(exception_class()) == exp
 
